package javadocExamplesFor240;

/**
 *An object that contains all information returned when
 *"<i>validateUser</i>" is called.
 *<br>
 *<b>Domain:</b>
 *<pre>
 *  result          : ValidationResult 
 *  firstName       : String
 *  lastName        : String
 *  numberOfRecords : int
 *  
 *  <i>Invariants</i>: result &ne; null AND
 *             firstName &ne; null AND isAlphabetic(name) AND |firstName| &ge; 1 AND
 *             lastName &ne; null AND isAlphabetic(name) AND |lastName| &ge; 1 AND
 *             numberOfRecords &ge; 0
 *</pre>
 */
public class ValidateUserOutput {
//Domain Implementation
	/**
	 * The validation result. Legal values are TRUE, FALSE, and, FAILED
	 * <pre>
	 * <b>Constraints</b>:
	 *   result &ne; null
	 * </pre>
	 */
	private ValidationResult result;
	
	/**
	 * The first name
	 * <pre>
	 * <b>Constraints</b>:
	 *   firstName &ne; null AND isAlphabetic(firstName) AND |firstName| &ge; 1
	 * </pre>
	 */
	private String firstName;
	
	/**
	 * The last name
	 * <pre>
	 * <b>Constraints</b>:
	 *   lastName &ne; null AND isAlphabetic(lastName) AND |lastName| &ge; 1
	 * </pre>
	 */
	private String lastName;
	
	/**
	 * The number of records
	 * <pre>
	 * <b>Constraints</b>:
	 *   numberOfRecords &ge; 0
	 * </pre>
	 */
	private int numberOfRecords;
	
//Constructors
	/**
	 *Creates the return object for the validate user command.
	 *<pre>
	 *<b>Constraints on the input</b>:
	 *   result &ne; null AND firstName &ne; null AND lastName &ne; null AND
	 *   numRecords &ge; 0 AND firstName.matches("[a-zA-z]+") AND
	 *   lastName.matches("[a-zA-Z]")
	 *
	 *<b>Result</b>
	 *   this.result = result AND this.firstName = firstName AND
	 *   this.lastName = lastName AND this.numRecords = numRecords
	 *</pre>
	 *@param result -- the result of the validation
	 *@param firstName -- the person's first name
	 *@param lastName -- the person's last name
	 *@param numRecords -- number of records
	 */
	public ValidateUserOutput(ValidationResult result, 
							  String firstName, 
							  String lastName, 
							  int numRecords)
	{
        //To be implemented later
	}

	/**
	 *The toString method
	 *<pre>
	 *<b>Constraints on the input</b>:
	 *  None
	 *</pre>
	 *@return
	 *<pre>A lexical representation of an instance of this class that satisfies
	 *the following grammar:
	 *   "ValidateUserOutput [result=" result ", firstName=" firstName
	 *   ", lastName=" lastName ", numRecords=" numRecords "]"   
	 *</pre>
	 */
	@Override
	public String toString() {
		//To be implemented later
		return null;
	}

	/**
	 *Result getter.
	 *<pre>
	 *<b>Constraints on the input</b>:
	 *  None
	 *</pre>
	 *@return the result.toString()
	 */
	public String getResult() {
		//To be implemented later
		return null;
	}

	/**
	 *FirstName getter.
	 *<pre>
	 *<b>Constraints on the input</b>:
	 *  None
	 *</pre>
	 *@return the firstName
	 */
	public String getFirstName() {
		return null;
	}

	/**
	 *LastName getter.
	 *<pre>
	 *<b>Constraints on the input</b>:
	 *  None
	 *</pre>
	 *@return the lastName
	 */
	public String getLastName() {
		//To be implemented later
		return null;
	}

	/**
	 *NumberOfRecords getter.
	 *<pre>
	 *<b>Constraints on the input</b>:
	 *  None
	 *</pre>
	 *@return the numberOfRecords
	 */
	public int getNumRecords() {
		//To be implemented later
		return 0;
	}
}
